Class: Azure::ARM::MachineLearning::Models::ServiceInputOutputSpecification
- Inherits:
-
Object
- Object
- Azure::ARM::MachineLearning::Models::ServiceInputOutputSpecification
- Includes:
- MsRestAzure
- Defined in:
- lib/generated/azure_mgmt_machine_learning/models/service_input_output_specification.rb
Overview
The swagger 2.0 schema describing the service’s inputs or outputs. See Swagger specification: swagger.io/specification/
Instance Attribute Summary collapse
-
#description ⇒ String
Swagger schema description.
-
#properties ⇒ Hash{String => TableSpecification}
schema for each input or output of the web service.
-
#title ⇒ String
Swagger schema title.
-
#type ⇒ String
‘object’.
Class Method Summary collapse
-
.mapper ⇒ Object
Mapper for ServiceInputOutputSpecification class as Ruby Hash.
Instance Attribute Details
#description ⇒ String
Returns Swagger schema description.
20 21 22 |
# File 'lib/generated/azure_mgmt_machine_learning/models/service_input_output_specification.rb', line 20 def description @description end |
#properties ⇒ Hash{String => TableSpecification}
schema for each input or output of the web service.
28 29 30 |
# File 'lib/generated/azure_mgmt_machine_learning/models/service_input_output_specification.rb', line 28 def properties @properties end |
#title ⇒ String
Returns Swagger schema title.
17 18 19 |
# File 'lib/generated/azure_mgmt_machine_learning/models/service_input_output_specification.rb', line 17 def title @title end |
#type ⇒ String
‘object’. Default value: ‘object’ .
24 25 26 |
# File 'lib/generated/azure_mgmt_machine_learning/models/service_input_output_specification.rb', line 24 def type @type end |
Class Method Details
.mapper ⇒ Object
Mapper for ServiceInputOutputSpecification class as Ruby Hash. This will be used for serialization/deserialization.
35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/generated/azure_mgmt_machine_learning/models/service_input_output_specification.rb', line 35 def self.mapper() { required: false, serialized_name: 'ServiceInputOutputSpecification', type: { name: 'Composite', class_name: 'ServiceInputOutputSpecification', model_properties: { title: { required: false, serialized_name: 'title', type: { name: 'String' } }, description: { required: false, serialized_name: 'description', type: { name: 'String' } }, type: { required: true, serialized_name: 'type', default_value: 'object', type: { name: 'String' } }, properties: { required: true, serialized_name: 'properties', type: { name: 'Dictionary', value: { required: false, serialized_name: 'TableSpecificationElementType', type: { name: 'Composite', class_name: 'TableSpecification' } } } } } } } end |